#!/usr/bin/env perl

use XyceRegression::Tools;

$Tools = XyceRegression::Tools->new();
# $Tools->setDebug(1);
# $Tools->setVerbose(1);

# The input arguments to this script are set up in 
# Xyce_Test/TestScripts/tsc_run_test_suite and are as follows:
# $1 = location of Xyce binary
# $2 = location of xyce_verify.pl script
# $3 = location of compare script 
# $4 = location of circuit file to test
# $5 = location of gold standard prn file

# If Xyce does not produce a prn file, then we return exit code 10.
# If Xyce succeeds, but the test fails, then we return exit code 2.
# If the shell script fails for some reason, then we return exit code 1.
# Otherwise we return the exit code of compare or xyce_verify.pl

# Since the shell script runs Xyce also, it is responsible for capturing any
# error output from Xyce.  The script run_xyce_regression captures the test
# output and handles the resulting files.  

$XYCE=$ARGV[0];
$XYCE_VERIFY=$ARGV[1];
#$XYCE_COMPARE=$ARGV[2];
#$CIRFILE=$ARGV[3];
#$GOLDPRN=$ARGV[4];

$CIR1="bug_624a.cir";
$CIR2="bug_624b.cir";

$PRN1="$CIR1.fred.out";
$PRN2="$CIR2.foo2.out";

$GOLD1="$CIR1.fred.out.gold";
$GOLD2="$CIR2.foo2.out.gold";

`rm -f $CIR1.fred.out`;
`rm -f $CIR1.HOMOTOPY.prn`;
$retval1 = $Tools->wrapXyceAndVerify($XYCE,$XYCE_VERIFY,$GOLD1,$CIR1,$PRN1);

`rm -f $CIR2.foo2.out`;
`rm -f $CIR2.HOMOTOPY.prn`;
$retval2 = $Tools->wrapXyceAndVerify($XYCE,$XYCE_VERIFY,$GOLD2,$CIR2,$PRN2);

$exitcode = $retval1;

if ( $retval1 == 14 ) 
{ 
  print STDERR "Could not find $PRN1\n";
} 
if ( $retval1 == 0 && ! -f "$CIR1.HOMOTOPY.prn" ) 
{ 
  print STDERR "Could not find $CIR1.HOMOTOPY.prn\n"; 
  $exitcode = 14 if ($exitcode == 0); 
}

$exitcode = $retval2 if ($exitcode == 0);

if ( $retval2 == 14 ) 
{ 
  print STDERR "Could not find $PRN2\n";
}

if ( $retval2 == 0 && ! -f "$CIR2.HOMOTOPY.prn" ) 
{ 
  print STDERR "Could not find $CIR2.HOMOTOPY.prn\n"; 
  $exitcode = 14 if ($exitcode == 0); 
}


print "Exit code = $exitcode\n"; exit $exitcode;
