#!/usr/bin/env perl

use XyceRegression::Tools;

$Tools = XyceRegression::Tools->new();

# The input arguments to this script are set up in
# Xyce_Test/TestScripts/tsc_run_test_suite and are as follows:
# $1 = location of Xyce binary
# $2 = location of xyce_verify.pl script
# $3 = location of compare script
# $4 = location of circuit file to test
# $5 = location of gold standard csv file

# If Xyce does not produce the appropriate output files, then we return exit code 14.
# If Xyce succeeds, but the test fails, then we return exit code 2.
# If the shell script fails for some reason, then we return exit code 1.

# Since the shell script runs Xyce and the comparison program, it is
# responsible for capturing any error output from Xyce and the STDOUT & STDERR
# from the comparison program.  The outside script, run_xyce_regression,
# expects the STDERR output from Xyce to go into $CIRFILE.err, the STDOUT
# output from comparison to go into $CIRFILE.csv.out and the STDERR output from
# comparison to go into $CIRFILE.csv.err.

$XYCE=$ARGV[0];
$XYCE_VERIFY=$ARGV[1];
$XYCE_COMPARE=$ARGV[2];
$CIRFILE=$ARGV[3];
$GOLDCSV=$ARGV[4];

$GOLDCSV =~ s/\.prn$//; # remove the .prn at the end.
$XYCE_ACVERIFY = $XYCE_VERIFY;
$XYCE_ACVERIFY =~ s/xyce_verify/ACComparator/;

system("rm -f $CIRFILE.HB.TD.csv");
$CMD="$XYCE $CIRFILE > $CIRFILE.out 2>$CIRFILE.err";

if (system($CMD) != 0)
    {
        `echo "Xyce EXITED WITH ERROR! on $CIRFILE" >> $CIRFILE.err`;
        $xyceexit=1;
    }
else
    {
        if (-z "$CIRFILE.err" ) {`rm -f $CIRFILE.err`;}
    }

if (defined ($xyceexit)) {print "Exit code = 10\n"; exit 10;}

if ( !(-f "$CIRFILE.HB.TD.csv")) {
    print STDERR "Missing output file $CIRFILE.HB.TD.csv\n";
    $xyceexit=14;
}

if ( !(-f "$CIRFILE.HB.FD.csv")) {
    print STDERR "Missing output file $CIRFILE.HB.FD.csv\n";
    $xyceexit=14;
}

if ( !(-f "$CIRFILE.hb_ic.csv")) {
    print STDERR "Missing output file $CIRFILE.hb_ic.csv\n";
    $xyceexit=14;
}

if (defined ($xyceexit)) {print "Exit code = $xyceexit\n"; exit $xyceexit;}

$retcode = 0;

#If this is a VALGRIND run, we don't do our normal verification, we
# merely run "valgrind_check.sh" as if it were xyce_verify.pl

if ($XYCE_VERIFY =~ m/valgrind_check/)
{
    print STDERR "DOING VALGRIND RUN INSTEAD OF REAL RUN!";
    if (system("$XYCE_VERIFY $CIRFILE $GOLDRAW $CIRFILE.prn > $CIRFILE.prn.out 2>&1 $CIRFILE.prn.err"))
    {
        print "Exit code = 2 \n";
        exit 2;
    }
    else
    {
        print "Exit code = 0 \n";
        exit 0;
    }
}

$CMD="$XYCE_VERIFY $CIRFILE $CIRFILE.HB.TD.csv $GOLDCSV.HB.TD.csv > $CIRFILE.HB.TD.csv.out 2> $CIRFILE.HB.TD.csv.err";
if (system("$CMD") != 0 ) {
    print STDERR "Verification failed on file $CIRFILE.HB.TD.csv, see $CIRFILE.HB.TD.csv.err\n";
    $retcode = 2;
}

$CMD="$XYCE_ACVERIFY $CIRFILE.HB.FD.csv $GOLDCSV.HB.FD.csv > $CIRFILE.HB.FD.csv.out 2> $CIRFILE.HB.FD.csv.err";
if (system("$CMD") != 0) {
    print STDERR "Verification failed on file $CIRFILE.HB.FD.csv, see $CIRFILE.HB.FD.csv.err\n";
    $retcode = 2;
}

$CMD="$XYCE_VERIFY $CIRFILE $CIRFILE.hb_ic.csv $GOLDCSV.hb_ic.csv > $CIRFILE.hb_ic.csv.out 2> $CIRFILE.hb_ic.csv.err";
if (system("$CMD") != 0 ) {
    print SFDERR "Verification failed on file $CIRFILE.hb_ic.csv, see $CIRFILE.hb_ic.csv.err\n";
    $retcode = 2;
}

print "Exit code = $retcode\n"; exit $retcode;
