#!/usr/bin/env perl
#
# The input current source,  IS.  The input current, defined by 
# a nonlinear dependent source, B1, is:
#
#   B1 = I = 10*t*e-5t   for t>0
#
# The voltage generated by the inductor is given by:
#
#   V(3) = L*dI/dt = L * d(10*t*e-5t)/dt  = 10 * L * e-5t  * (1 - 5t)
#
# where, the inductance, L, is given by:
#
#  L = baseL*factor;
#
#  baseL = 10mH = 0.01;
#  temp = 363.15;
#  tnom=300.15;
#  TC1=0.01;
#  TC2=0.926e-4;
#
#  difference = temp - tnom;
#  factor = 1.0 + (TC1)*difference +
#                 (TC2)*difference*difference;
#
#         = 1.99753;
#
#  L = baseL*factor;
#
 
$baseL = 0.01;
$temp = 363.15;
$tnom=300.15;
$TC1=0.01;
$TC2=0.926e-4;
$difference = $temp - $tnom;
$factor=1.0 + $TC1*$difference + $TC2*$difference*$difference;
$L = $baseL*$factor;

open(INPUT,"tempind.cir.prn");
open(OUTPUT,">tempind.cir.prn.gs");
while ($line = <INPUT>)
{
  # Handle first and last lines:
  if ($line =~ m/^[IE]/) 
  { 
    print OUTPUT "$line"; 
    next; 
  }
  @s = split(" ",$line);

  # current:
  $time=$s[1];
  $current = 0.0;
  if ($time>0.0)
  {
    $current = 10.0*$time*exp(-5.0*$time);
  }

  # voltage:
  $voltage = 0.0;
  if ($time>0.0)
  {
    $voltage = 10.0 * $L * exp(-5*$time)*(1.0 - 5.0*$time);
  }

  printf OUTPUT "%3d   %14.8e   %14.8e   %14.8e   \n",
    $s[0],$s[1],$current,$voltage;

}
close(INPUT);
close(OUTPUT);

